==> openGion6.6.0.1_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE62S.sql <==
/****************************************************************************/
/* GE62 ( 伝送定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2016/10/27 10:57:15                                            */
/****************************************************************************/

CREATE TABLE GE62 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID           */
 , KBREAD       varchar           (  20 )                   NOT NULL            /*  20 読取方法         */
 , READOBJ      varchar           ( 200 )                   NOT NULL            /*  30 読取対象         */
 , READPRM      varchar           ( 200 )                                       /*  40 読取ﾊﾟﾗﾒｰﾀｰ      */
 , KBEXEC       varchar           (  20 )                   NOT NULL            /*  50 実行方法         */
 , EXECDBID     varchar           ( 100 )                                       /*  60 実行DB接続先ID   */
 , EXECOBJ      varchar           ( 200 )                   NOT NULL            /*  70 実行対象         */
 , EXECPRM      varchar           ( 200 )                                       /*  80 実行ﾊﾟﾗﾒｰﾀｰ      */
 , DMN_GRP      varchar           (  20 )                   NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ      */
 , DMN_TIME     INTEGER                         DEFAULT 60  NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔        */
 , ERROR_SENDTO varchar           ( 200 )                                       /* 110 ｴﾗｰ送信先        */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時         */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG           */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG         */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員         */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時         */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG           */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG         */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者           */
);

==> openGion6.8.4.2_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE62S.sql <==
/****************************************************************************/
/* GE62 ( 伝送定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE62 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID           */
 , KBREAD       varchar           (  20 )                   NOT NULL            /*  20 読取方法         */
 , READOBJ      varchar           ( 200 )                   NOT NULL            /*  30 読取対象         */
 , READPRM      varchar           ( 200 )                                       /*  40 読取ﾊﾟﾗﾒｰﾀｰ      */
 , KBEXEC       varchar           (  20 )                   NOT NULL            /*  50 実行方法         */
 , EXECDBID     varchar           ( 100 )                                       /*  60 実行DB接続先ID   */
 , EXECOBJ      varchar           ( 200 )                   NOT NULL            /*  70 実行対象         */
 , EXECPRM      varchar           ( 200 )                                       /*  80 実行ﾊﾟﾗﾒｰﾀｰ      */
 , DMN_GRP      varchar           (  20 )                   NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ      */
 , DMN_TIME     INTEGER                         DEFAULT 60  NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔        */
 , ERROR_SENDTO varchar           ( 200 )                                       /* 110 ｴﾗｰ送信先        */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          varchar           (   1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時         */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG           */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG         */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員         */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時         */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG           */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG         */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者           */
);
